@@ -1,6 +1,7 @@
 from pathlib import Path
 
 import typer
+from odd_dbt.app import app as dbt_test_app
 from oddrn_generator.generators import FilesystemGenerator
 
 from odd_cli.client import Client
@@ -13,6 +14,7 @@ app.add_typer(
     tokens_app,
     name="tokens",
 )
+app.add_typer(dbt_test_app, name="dbt")
 
 
 @app.command()
@@ -24,15 +26,18 @@ def collect(
     ),
 ):
     "Collect and ingest metadata for local files from folder"
-    client = Client(host=platform_host)
+    client = Client(host=platform_host, token=platform_token)
 
     generator = FilesystemGenerator(host_settings="local")
 
-    client.ingest_data_source(generator.get_data_source_oddrn(), platform_token)
+    client.create_data_source(
+        data_source_oddrn=generator.get_data_source_oddrn(),
+        data_source_name="local_files",
+    )
 
     data_entities = read(path=folder, generator=generator)
 
-    client.ingest_data_entities(data_entities, platform_token)
+    client.ingest_data_entity_list(data_entities=data_entities)
 
     logger.success(f"Ingested {len(data_entities.items)} datasets")
 
